@@ -59,11 +59,11 @@ The behavior can be change:
     '8/9'
 """
 
-__title__ = 'flatlatex'
-__author__ = 'Jean-Benoist Leger'
-__licence__ = 'BSD-2'
+__title__ = "flatlatex"
+__author__ = "Jean-Benoist Leger"
+__licence__ = "BSD-2"
 
-version_info = (0, 8)
-__version__ = '.'.join(map(str, version_info))
+version_info = (0, 9)
+__version__ = ".".join(map(str, version_info))
 
 from .conv import converter
